@@ -68,13 +68,13 @@ class FileCache():
                 self.create_artifacts(
                     key=key,
                     namespace=self.namespace,
-                    name=artifacts_config['name'],
+                    name=artifacts_config.get('name'),
                     engine=self.default_engine.__class__.__name__,
-                    describe=artifacts_config['describe'],
-                    jenkins_jobs_id=artifacts_config['jenkins_jobs_id'],
-                    build_id=artifacts_config['build_id'],
-                    ttl=artifacts_config['ttl'],
-                    is_scan_code_download=artifacts_config['is_scan_code_download']
+                    describe=artifacts_config.get('describe'),
+                    jenkins_jobs_id=artifacts_config.get('jenkins_jobs_id'),
+                    build_id=artifacts_config.get('build_id'),
+                    ttl=artifacts_config.get('ttl'),
+                    is_scan_code_download=artifacts_config.get('is_scan_code_download')
                 )
 
             for area in self.available_area:
@@ -86,13 +86,13 @@ class FileCache():
                         self.create_artifacts(
                             key=key,
                             namespace=self.namespace,
-                            name=artifacts_config['name'],
+                            name=artifacts_config.get('name'),
                             engine=engine.__class__.__name__,
-                            describe=artifacts_config['describe'],
-                            jenkins_jobs_id=artifacts_config['jenkins_jobs_id'],
-                            build_id=artifacts_config['build_id'],
-                            ttl=artifacts_config['ttl'],
-                            is_scan_code_download=artifacts_config['is_scan_code_download']
+                            describe=artifacts_config.get('describe'),
+                            jenkins_jobs_id=artifacts_config.get('jenkins_jobs_id'),
+                            build_id=artifacts_config.get('build_id'),
+                            ttl=artifacts_config.get('ttl'),
+                            is_scan_code_download=artifacts_config.get('is_scan_code_download')
                         )
         else:
             is_set = self.default_engine.set_namespace(namespace=self.namespace).set(key=key, file_path=file_path,
@@ -101,19 +101,19 @@ class FileCache():
                 self.create_artifacts(
                     key=key,
                     namespace=self.namespace,
-                    name=artifacts_config['name'],
+                    name=artifacts_config.get('name'),
                     engine=self.default_engine.__class__.__name__,
-                    describe=artifacts_config['describe'],
-                    jenkins_jobs_id=artifacts_config['jenkins_jobs_id'],
-                    build_id=artifacts_config['build_id'],
-                    ttl=artifacts_config['ttl'],
-                    is_scan_code_download=artifacts_config['is_scan_code_download']
+                    describe=artifacts_config.get('describe'),
+                    jenkins_jobs_id=artifacts_config.get('jenkins_jobs_id'),
+                    build_id=artifacts_config.get('build_id'),
+                    ttl=artifacts_config.get('ttl'),
+                    is_scan_code_download=artifacts_config.get('is_scan_code_download')
                 )
 
         return is_set
 
     def create_artifacts(self, key, namespace, engine, name=None, describe=None, jenkins_jobs_id=None, build_id=None,
-                         ttl=60 * 60 * 24 * 15,
+                         ttl=None,
                          is_scan_code_download=False):
         path = "%s/%s" % (namespace, key)
         try:
@@ -129,7 +129,7 @@ class FileCache():
                     'engine': engine,
                     'jenkins_jobs_id': jenkins_jobs_id,
                     'build_id': build_id,
-                    'ttl': ttl,
+                    'ttl': 1296000 if ttl is None else ttl,
                     'is_scan_code_download': 1 if is_scan_code_download else 0,
                 }
             )
@@ -169,7 +169,7 @@ class FileCache():
             return False
 
     @runtime_logging
-    def delete(self, key, delete_all_area=False):
+    def delete(self, key=None, delete_all_area=False):
         if delete_all_area:
             self.default_engine.set_namespace(namespace=self.namespace).delete(key=key)
 
